% A misnomer! the function computes the received power at a location from each base station, not the spectral
% efficiency
function [allSignalLevels,distance] = computeSpectralEfficiency(BS, paramSet, xCoordinate, yCoordinate, index, beta)
                                      
    dist                    = [];
    nSectors                = 3;

    signalLevel             = zeros(nSectors, paramSet.system.nBS,paramSet.system.numSamples);
    signalLevelLOS          = zeros(nSectors, paramSet.system.nBS,paramSet.system.numSamples);
    signalLevelNLOS         = zeros(nSectors, paramSet.system.nBS,paramSet.system.numSamples);
    dist                    = zeros(paramSet.system.nBS);
    
    for iBS = 1:paramSet.system.nBS %length(BS)
    	typeBS              = BS(iBS).type;
        deltaCoordinates    = [xCoordinate,yCoordinate] - BS(iBS).coordinates;
        dist(iBS)           = norm(deltaCoordinates, 2);
 
        if (typeBS == 1)
            
        	[theta, rho]    = cart2pol(deltaCoordinates(1), deltaCoordinates(2));
            
            for iTheta = 1:nSectors
            	arcSector   = (iTheta-1) * 2*pi/nSectors + 2*pi/(2*nSectors);
                if (pi < arcSector)
                	arcSector = - (2*pi - arcSector);
                elseif (arcSector <= -pi)
                	arcSector = 2*pi + arcSector;
                end
                arc         = theta - arcSector;
                if (pi < arc)
                	phi(iTheta)   = - (2*pi - arc);
                elseif (arc <= -pi)
                	phi(iTheta)   = 2*pi + arc;
                else
                	phi(iTheta)   = arc;
                end
             end
             antennaPattern  = dirAntPattern(180/pi*phi);
             clear phi;
         
             [logpathlossLOS, logpathlossNLOS]   = computeLogPathloss(paramSet, typeBS, dist(iBS)); % pathloss in dB units
             logpathlossLOSPenetLoss             = logpathlossLOS  + paramSet.macro.PenetLoss;
             logpathlossNLOSPenetLoss            = logpathlossNLOS + paramSet.macro.PenetLoss;
             
             probLOS                             = min(18/dist(iBS), 1)*(1-exp(-dist(iBS)/63))+exp(-dist(iBS)/63);
             
             for mm=1:paramSet.system.numSamples
                 if(dist(iBS) < paramSet.macro.rBreak)
                    shadowingLOS                 = normrnd(0,paramSet.macro.sigma(1));
                 else
                     shadowingLOS                = normrnd(0,paramSet.macro.sigma(2));                    
                 end
                 shadowingNLOS                   = normrnd(0,paramSet.macro.sigma(3));
                 
                 probPenetLoss                   = 0.5;
                 
                 signalLevelLOS(:, iBS,mm)       = (1-probPenetLoss)*(10.^((paramSet.system.Peffective(index) - logpathlossLOS + antennaPattern + shadowingLOS)./10))' + ...
                                                   (probPenetLoss)*(10.^((paramSet.system.Peffective(index) - logpathlossLOSPenetLoss  + antennaPattern + shadowingLOS)./10))';
                                           
                 signalLevelNLOS(:, iBS,mm)      = (1-probPenetLoss)*(10.^((paramSet.system.Peffective(index) - logpathlossNLOS + antennaPattern + shadowingNLOS)./10))' + ...
                                                   (probPenetLoss)*(10.^((paramSet.system.Peffective(index) - logpathlossNLOSPenetLoss + antennaPattern + shadowingNLOS)./10))';
            end
            signalLevel(:, iBS,:)                = probLOS *  signalLevelLOS(:,iBS,:) + (1-probLOS) * signalLevelNLOS(:,iBS,:);
            
        else  % nano sites
              [logpathlossLOS, logpathlossNLOS]  = computeLogPathloss(paramSet, typeBS, dist(iBS)); % pathloss in dB units
             
              logpathlossLOSPenetLoss            = logpathlossLOS + paramSet.nano.PenetLoss;
              logpathlossNLOSPenetLoss           = logpathlossNLOS + paramSet.nano.PenetLoss;

              probLOS                            =  min(18./dist(iBS), 1).*(1-exp(-dist(iBS)/36))+exp(-dist(iBS)/36);
              
              for mm=1:paramSet.system.numSamples
                 if(dist(iBS) < paramSet.nano.rBreak)
                    shadowingLOS                 = normrnd(0,paramSet.nano.sigma(1));
                 else
                     shadowingLOS                = normrnd(0,paramSet.nano.sigma(2));
                 end
                 shadowingNLOS                   = normrnd(0,paramSet.nano.sigma(3));
                 
                 probPenetLoss                   = computePenetLoss( beta, dist(iBS));
                 
                 %PLOS = 1 for indoor users
                 signalLevelLOS(:, iBS,mm)       = (1-probPenetLoss)*(10.^((paramSet.system.Peffective(1) - logpathlossLOS + shadowingLOS  + [0; -Inf*ones(nSectors-1, 1)])./10)) + ...
                                                  (probPenetLoss)*probLOS*(10.^((paramSet.system.Peffective(1) - logpathlossLOSPenetLoss + shadowingLOS  + [0; -Inf*ones(nSectors-1, 1)])./10));
                                              
                 %Signal level outdoor
                 signalLevelNLOS(:, iBS,mm)      = (probPenetLoss)*(1-probLOS)*(10.^((paramSet.system.Peffective(1) - logpathlossNLOSPenetLoss + shadowingNLOS+ [0; -Inf*ones(nSectors-1, 1)])./10)); 
              end
              signalLevel(:, iBS,:)              = signalLevelLOS(:,iBS,:) + signalLevelNLOS(:,iBS,:);%  probLOS *  signalLevelLOS(:,iBS,:) + (1-probLOS) * signalLevelNLOS(:,iBS,:);
        end         
    end
    
    allSignalLevels = signalLevel;    
    distance = dist;
    
end
