% computes the effective transmit power of macro and micro base stations
% for different cell radii
function [ptxEffective, Ptx_W] = ptransmit(paramSet,interSiteDistance,beta)
    
    const                 = 1;%log(10)/10;
    ptx                   = [];
    P_W                   = [];
    check                 = 0;
    ptmi                  = -15;

    
    while check  == 0

            RMin = 0.00001;   
            dist = paramSet.nano.radius;%+20

            argumentLOS            = @(r) (1/(paramSet.nano.sigma(1)*const).* (paramSet.system.sensitivity - ptmi ...
                                    + paramSet.nano.U(1) +  paramSet.nano.lambda(1)*10*log10(r))); 
            
            argumentLOSPenetLoss   = @(r) (1/(paramSet.nano.sigma(1)*const).* (paramSet.system.sensitivity - ptmi ...
                                    + paramSet.nano.U(1) + paramSet.nano.PenetLoss  + paramSet.nano.lambda(1)*10*log10(r)));
                            
            argumentNLOS           = @(r) (1/(paramSet.nano.sigma(3)*const).* (paramSet.system.sensitivity - ptmi ...
                                    + paramSet.nano.U(3) + paramSet.nano.lambda(3)*10*log10(r))); 
                            
            argumentNLOSPentLoss   = @(r) (1/(paramSet.nano.sigma(3)*const).* (paramSet.system.sensitivity - ptmi ...
                                    + paramSet.nano.U(3) + paramSet.nano.PenetLoss + paramSet.nano.lambda(3)*10*log10(r))); 
                            
            plos            = @(r) (min(18./r,1).*(1 - exp(-r./36)) + exp(-r./36));
            
            Ppenetlos       = @(r) computePenetLoss(beta, r);% 0.5;
            
            clos            = @(r) (r .* 0.5 .* erfc(argumentLOS(r)/sqrt(2))).*plos(r).*(1-Ppenetlos(r));
            CLOS            = @(R) (2./(R^2) .* quad(clos, RMin, R));

            closPenetLoss   = @(r) (r .* 0.5 .* erfc(argumentLOSPenetLoss(r)/sqrt(2))).*plos(r).*Ppenetlos(r);
            CLOSPENETLOSS   = @(R) (2./(R^2) .* quad(closPenetLoss, RMin, R));
            
            cnlos           = @(r) (r .* 0.5 .* erfc(argumentNLOS(r)/sqrt(2))).*(1-plos(r)).*(1-Ppenetlos(r));
            CNLOS           = @(R) (2./(R^2) .* quad(cnlos, RMin, R));

            cnlosPenetLoss  = @(r) (r .* 0.5 .* erfc(argumentNLOSPentLoss(r)/sqrt(2))).*(1-plos(r)).*Ppenetlos(r);
            CNLOSPENETLOSS  = @(R) (2./(R^2) .* quad(cnlosPenetLoss, RMin, R));
            
            %plos            =(min(18./dist,1).*(1 - exp(-dist./36)) + exp(-dist./36));
            %coverage        = plos*CLOS(dist) + (1-plos)*CNLOS(dist)

            coverage        = CLOS(dist) + CLOSPENETLOSS(dist) + CNLOS(dist) + CNLOSPENETLOSS(dist);

            if coverage >= 0.95% cov          
                    check =1;
            else
                ptmi = ptmi + 0.5;
            end
    end
    
    ptx(end + 1) = ptmi;

    PperSubcarrier  = ptmi  - 2 - 10*log10(1);
    P_dBm           = PperSubcarrier + 10*log10(300) - (-1);
    P_W(end +1)     = 10^(P_dBm/10)*1e-3;

    %===============================
    
    ptma = 0;

    for D=interSiteDistance % Dmax
  
        dist = D/sqrt(3);%+ 40;
        RMin1 = 0.00001;
        RMin2 = paramSet.macro.rBreak;

        check = 0;
        while check ~= 1 
    
           argumentLOS1           = @(r) (1/(paramSet.macro.sigma(1)*const).* (paramSet.system.sensitivity - ptma ...
                                    + paramSet.macro.U(1) + paramSet.macro.lambda(1)*10*log10(r)));
           
           argumentLOS1PenetLoss  = @(r) (1/(paramSet.macro.sigma(1)*const).* (paramSet.system.sensitivity - ptma ...
                                    + paramSet.macro.U(1) + paramSet.macro.PenetLoss + paramSet.macro.lambda(1)*10*log10(r)));
                       
           argumentLOS2           = @(r) (1/(paramSet.macro.sigma(2)*const).* (paramSet.system.sensitivity - ptma ...
                                    + paramSet.macro.U(2) +  paramSet.macro.lambda(2)*10*log10(r))); 
                        
           argumentLOS2PenetLoss  = @(r) (1/(paramSet.macro.sigma(2)*const).* (paramSet.system.sensitivity - ptma ...
                                    + paramSet.macro.U(2) + paramSet.macro.PenetLoss + paramSet.macro.lambda(2)*10*log10(r)));             
           
           argumentNLOS           = @(r) (1/(paramSet.macro.sigma(3)*const).* (paramSet.system.sensitivity - ptma ...
                                    + paramSet.macro.U(3) + paramSet.macro.lambda(3)*10*log10(r)));
              
           argumentNLOSPenetLoss  = @(r) (1/(paramSet.macro.sigma(3)*const).* (paramSet.system.sensitivity - ptma ...
                                    + paramSet.macro.U(3) + paramSet.macro.PenetLoss + paramSet.macro.lambda(3)*10*log10(r)));
    
                                
            plos            = @(r) (min(18./r,1).*(1 - exp(-r./63)) + exp(-r./63));
            PpenetLoss      = 0.5;
            
            clos1           = @(r) (r .* 0.5 .* erfc(argumentLOS1(r)/sqrt(2))).*plos(r)*(1-PpenetLoss);
            CLOS1           = @(R) (2./(R^2) .* quad(clos1, RMin1, R));

            clos1PenetLoss           = @(r) (r .* 0.5 .* erfc(argumentLOS1PenetLoss(r)/sqrt(2))).*plos(r)*(PpenetLoss);
            CLOS1PenetLoss           = @(R) (2./(R^2) .* quad(clos1PenetLoss, RMin1, R));
            
            clos2           = @(r) (r .* 0.5 .* erfc(argumentLOS2(r)/sqrt(2))).*plos(r)*(1-PpenetLoss);
            CLOS2           = @(R) (2./(R^2) .* quad(clos2, RMin2, R));


            clos2PenetLoss           = @(r) (r .* 0.5 .* erfc(argumentLOS2PenetLoss(r)/sqrt(2))).*plos(r)*PpenetLoss;
            CLOS2PenetLoss           = @(R) (2./(R^2) .* quad(clos2PenetLoss, RMin2, R));

            
            cnlos           = @(r) (r .* 0.5 .* erfc(argumentNLOS(r)/sqrt(2))).*(1-plos(r))*(1-PpenetLoss);
            CNLOS           = @(R) (2./(R^2) .* quad(cnlos, RMin1, R));

            cnlosPenetLoss           = @(r) (r .* 0.5 .* erfc(argumentNLOSPenetLoss(r)/sqrt(2))).*(1-plos(r))*PpenetLoss;
            CNLOSPenetLoss           = @(R) (2./(R^2) .* quad(cnlosPenetLoss, RMin1, R));

            
            %plos =(min(18./dist,1).*(1 - exp(-dist./63)) + exp(-dist./63));
            %coverage = plos*(CLOS1(RMin2)+CLOS2(dist)) + (1-plos)* CNLOS(dist);
            
            coverage = CLOS1(RMin2) + CLOS1PenetLoss(RMin2) + CLOS2(dist) + CLOS2PenetLoss(dist) + CNLOS(dist) + CNLOSPenetLoss(dist);
            
            if coverage >= 0.95% cov          
                    check =1;
            else
                ptma = ptma + 0.5;
            end
        end
        
        ptx(end + 1)    = ptma; 
       
        PperSubcarrier  = ptma  - 15 - 10*log10(2);
        P_dBm           = PperSubcarrier + 10*log10(300) - (-1);
        P_W(end + 1)      = 10.^(P_dBm./10).*1e-3;
            
    end
    ptxEffective    = ptx %in dBm
    Ptx_W           = P_W %in watts for power consumption computation
    
    %powerconsumption(P_W)
end    